@@ -2,7 +2,7 @@
  * ark -- archiver for the KDE project
  *
  * Copyright (C) 2009 Harald Hvaal <haraldhv@stud.ntnu.no>
- * Copyright (C) 2009-2011 Raphael Kubo da Costa <kubito@gmail.com>
+ * Copyright (C) 2009-2011 Raphael Kubo da Costa <rakuco@FreeBSD.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -73,9 +73,9 @@ ParameterList CliPlugin::parameterList() const
 
     if (p.isEmpty()) {
         p[CaptureProgress] = false;
-        p[ListProgram] = QLatin1String( "zipinfo" );
-        p[ExtractProgram] = QLatin1String( "unzip" );
-        p[DeleteProgram] = p[AddProgram] = QLatin1String( "zip" );
+        p[ListProgram] = QStringList() << QLatin1String( "zipinfo" );
+        p[ExtractProgram] = QStringList() << QLatin1String( "unzip" );
+        p[DeleteProgram] = p[AddProgram] = QStringList() << QLatin1String( "zip" );
 
         p[ListArgs] = QStringList() << QLatin1String( "-l" ) << QLatin1String( "-T" ) << QLatin1String( "$Archive" );
         p[ExtractArgs] = QStringList() << QLatin1String( "$PreservePathSwitch" ) << QLatin1String( "$PasswordSwitch" ) << QLatin1String( "$Archive" ) << QLatin1String( "$Files" );
@@ -131,7 +131,7 @@ bool CliPlugin::readListLine(const QString &line)
             e[Timestamp] = ts;
 
             e[FileName] = e[InternalID] = entryPattern.cap(10);
-            entry(e);
+            emit entry(e);
         }
         break;
     }
